@@ -2,7 +2,7 @@
 #
 # SPDX-License-Identifier: Apache-2.0
 
-__version__ = "4.1.5"
+__version__ = "4.1.10"
 
 import logging
 import os, time
@@ -214,7 +214,7 @@ def install_libs(path, ucc_lib_target):
         ucc_lib_target (str): Target path to install libraries.
     """
 
-    def _install_libs(requirements, ucc_target, installer="pip3"):
+    def _install_libs(requirements, ucc_target, installer="python3"):
         """
         Install 3rd Party libraries using pip2/pip3
 
@@ -229,7 +229,7 @@ def install_libs(path, ucc_lib_target):
             if not os.path.exists(ucc_target):
                 os.makedirs(ucc_target)
             install_cmd = (
-                installer +" install -r \""
+                installer +" -m pip install -r \""
                 + requirements
                 + "\" --no-compile --prefer-binary --ignore-installed --target \""
                 + ucc_target
@@ -249,10 +249,10 @@ def install_libs(path, ucc_lib_target):
 
     if os.path.exists(os.path.join(path,"lib","py2", "requirements.txt")):
         logging.info(f"  Uses py2 requirements")    
-        _install_libs(requirements=os.path.join(path,"lib","py2", "requirements.txt"), installer="pip2", ucc_target=os.path.join(ucc_lib_target, "py2"))
+        _install_libs(requirements=os.path.join(path,"lib","py2", "requirements.txt"), installer="python2", ucc_target=os.path.join(ucc_lib_target, "py2"))
     elif os.path.exists(os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements_py2.txt")):
         logging.info(f"  Uses py2 requirements")    
-        _install_libs(requirements=os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements_py2.txt"), installer="pip2", ucc_target=os.path.join(ucc_lib_target, "py2"))        
+        _install_libs(requirements=os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements_py2.txt"), installer="python2", ucc_target=os.path.join(ucc_lib_target, "py2"))        
     else:
         logging.info(f"  Not using py2 requirements")    
 
@@ -261,7 +261,7 @@ def install_libs(path, ucc_lib_target):
         _install_libs(requirements=os.path.join(path,"lib", "py3","requirements.txt"), ucc_target=os.path.join(ucc_lib_target, "py3"))
     elif os.path.exists(os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements_py3.txt")):
         logging.info(f"  Uses py3 requirements")    
-        _install_libs(requirements=os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements_py3.txt"), installer="pip3", ucc_target=os.path.join(ucc_lib_target, "py2"))        
+        _install_libs(requirements=os.path.join(os.path.abspath(os.path.join(path, os.pardir)), "requirements_py3.txt"), installer="python3", ucc_target=os.path.join(ucc_lib_target, "py2"))        
     else:
         logging.info(f"  Not using py3 requirements")    
 
@@ -429,6 +429,21 @@ def add_modular_input(
         with open(input_file_name, "w") as input_file:
             input_file.write(content)
 
+        input_default = os.path.join(
+            outputdir, ta_name, "default",  "inputs.conf"
+        )   
+        config = configparser.ConfigParser()
+        if os.path.exists(input_default):
+            config.read(input_default)
+        
+        if config.has_section(input_name):
+            config[input_name]['python.version'] = 'python3'
+        else:
+            config[input_name] = {'python.version': 'python3'}
+        
+        with open(input_default, 'w') as configfile:
+           config.write(configfile)
+
 
 def make_modular_alerts(args, ta_name, ta_namespace, schema_content):
     """
@@ -480,7 +495,10 @@ def remove_listed_files(ignore_list):
     """
     for path in ignore_list:
         if os.path.exists(path):
-            shutil.rmtree(path, ignore_errors=True)
+            if os.path.isfile(path):
+                os.remove(path)
+            elif os.path.isdir(path):
+                shutil.rmtree(path, ignore_errors=True)
         else:
             logger.info("While ignoring the files mentioned in .uccignore {} was not found".format(path))
 
@@ -582,6 +600,11 @@ def main():
 
     clean_before_build()
 
+    manifest= None
+    with open(os.path.abspath(os.path.join(args.source, "app.manifest")), "r") as manifest_file:
+        manifest = json.load(manifest_file)
+        ta_name = manifest['info']['id']['name']
+
     if os.path.exists(args.config):
 
         if args.ta_version:
@@ -591,7 +614,7 @@ def main():
         schema_content = handle_update(args.config)
 
         scheme = GlobalConfigBuilderSchema(schema_content, j2_env)
-        ta_name = schema_content.get("meta").get("name")
+        
         ta_version = schema_content.get("meta").get("version")
         ta_tabs = schema_content.get("pages").get("configuration").get("tabs")
         ta_namespace = schema_content.get("meta").get("restRoot")
@@ -638,7 +661,6 @@ def main():
         logger.warning("Skipped Generating UI components as GlobalConfig.json does not exist.")
         logger.info("Setting TA name as generic")
 
-        ta_name = "TA-generic"
         ucc_lib_target = os.path.join(outputdir, ta_name, "lib")
 
         install_libs(
@@ -690,4 +712,11 @@ def main():
     app_config['ui']['label']=manifest['info']['title']
 
     with open(os.path.join(outputdir, ta_name,'default', "app.conf"), 'w') as configfile:
-        app_config.write(configfile)
\ No newline at end of file
+        app_config.write(configfile)
+
+    #Copy Licenses
+    license_dir = os.path.abspath(os.path.join(args.source, PARENT_DIR, "LICENSES"))
+    
+    if os.path.exists(license_dir):        
+        logger.info("Copy LICENSES directory ")
+        recursive_overwrite(license_dir, os.path.join(outputdir, ta_name,"LICENSES"))
